@@ -22,20 +22,24 @@ using namespace Rcpp ;
 
 RCPP_MODULE (VAR_MLP) {
 
+/* 'The VARMLP module */
   class_<CRcppExport> ("VAR_MLP")
         .constructor <Rcpp::DataFrame, unsigned, Rcpp::IntegerVector, unsigned, bool > ()
         .property("MSE", &CRcppExport::getSSR, "mean squared error of the model on training data")
         //.method ("fit", &CRcppExport::fit, "fit the model")
-        .method ("train", &CRcppExport::train, "Use the NN to learn from data")
-        .method ("forecast", &CRcppExport::forecast, "Provides the predictions of the input data")
+        .method ("train", &CRcppExport::train, "Update the model from input data")
+        .method ("forecast", &CRcppExport::forecast, "Computes the predictions")
     ;
 }
+/* 'The dickey fuller test module. */
 RCPP_MODULE (DickeyFuller) {
   class_<DickeyFuller> ("DickeyFuller")
         .constructor <Rcpp::NumericVector, int> ()
         .method ("summary", &DickeyFuller::summary, "Summary of the test")
         .property ("df", &DickeyFuller::getDF, "return the value of test");
 }
+
+/* 'The Granger causality test module. */
 RCPP_MODULE (CausalityTest) {
   class_<CausalityTest> ("CausalityTest")
         .constructor <Rcpp::NumericVector, Rcpp::NumericVector, int, bool> ()
@@ -44,7 +48,7 @@ RCPP_MODULE (CausalityTest) {
         .method ("summary", &CausalityTest::summary, "Summary of the test")
     ;
 }
- /*' Class for the non linear Granger CausalityTest. */
+ /*'The non linear Granger CausalityTest module. */
  RCPP_MODULE (NlinCausalityTest) {
     class_<DynamicCausalityTest> ("DynamicCausalityTest")
         .constructor <  Rcpp::NumericVector,
